@@ -103,12 +103,19 @@ public class VCalendar extends VObject {
 
     @Override
     public void addVObject(VObject vObject) {
-        super.addVObject(vObject);
         if (firstVevent == null && ("VEVENT".equals(vObject.type) || "VTODO".equals(vObject.type))) {
             firstVevent = vObject;
         }
         if ("VTIMEZONE".equals(vObject.type)) {
-            vTimezone = vObject;
+            if (vTimezone == null) {
+                vTimezone = vObject;
+            } else if (vTimezone.getPropertyValue("TZID").equals(vObject.getPropertyValue("TZID"))){
+                // drop duplicate TZID definition (Korganizer bug)
+                vObject = null;
+            }
+        }
+        if (vObject != null) {
+            super.addVObject(vObject);
         }
     }
 
@@ -349,6 +356,21 @@ public class VCalendar extends VObject {
                 }
             }
         }
+        
+        // validate RRULE - COUNT and UNTIL may not occur at once
+        if (vTimezone != null && vTimezone.vObjects != null) {
+            for (VObject vObject : vTimezone.vObjects) {
+                VProperty rrule = vObject.getProperty("RRULE");
+                if (rrule != null) {
+                    Map<String, String> rruleValueMap = rrule.getValuesAsMap();
+                    if (rruleValueMap.containsKey("UNTIL") && rruleValueMap.containsKey("COUNT")) {
+                        rrule.removeValue("UNTIL="+rruleValueMap.get("UNTIL"));
+                    }
+                }
+            }
+        }
+        // end validate RRULE
+        
         // convert TZID to Exchange time zone id
         ResourceBundle tzBundle = ResourceBundle.getBundle("exchtimezones");
         ResourceBundle tzidsBundle = ResourceBundle.getBundle("stdtimezones");
@@ -851,11 +873,12 @@ public class VCalendar extends VObject {
     }
 
     public TimeZone getStandardTimezoneId(String tzid) {
-        String convertedTzid = null;
+        String convertedTzid;
         // convert Exchange TZID to standard timezone
         try {
             convertedTzid = ResourceBundle.getBundle("timezones").getString(tzid);
         } catch (MissingResourceException e) {
+            convertedTzid = tzid;
             // failover: detect timezone from offset
             VObject vTimezone = getVTimezone();
             for (VObject tzDefinition : vTimezone.vObjects) {
@@ -864,7 +887,7 @@ public class VCalendar extends VObject {
                     convertedTzid = ResourceBundle.getBundle("tzoffsettimezones").getString(tzOffset);
                 }
             }
-            convertedTzid = ResourceBundle.getBundle("timezones").getString(tzid);
+            convertedTzid = ResourceBundle.getBundle("timezones").getString(convertedTzid);
         }
         return TimeZone.getTimeZone(convertedTzid);
 
@@ -872,7 +895,7 @@ public class VCalendar extends VObject {
 
     public String convertCalendarDateToExchangeZulu(String vcalendarDateValue, String tzid) throws IOException {
         String zuluDateValue = null;
-        TimeZone timeZone = null;
+        TimeZone timeZone;
         if (tzid == null) {
             timeZone = ExchangeSession.GMT_TIMEZONE;
         } else {
