@@ -275,8 +275,6 @@ public class ExchangeFormAuthenticator implements ExchangeAuthenticator {
                 if (cookie.getName().startsWith("cadata") || "sessionid".equals(cookie.getName())
                         // Exchange 2007 cookie
                         || "UserContext".equals(cookie.getName())
-                        // Direct EWS access
-                        || "exchangecookie".equals(cookie.getName())
                 ) {
                     authenticated = true;
                     break;
