@@ -1,5 +1,5 @@
 /*
-* DavMail POP/IMAP/SMTP/CalDav/LDAP Exchange Gateway
+ * DavMail POP/IMAP/SMTP/CalDav/LDAP Exchange Gateway
  * Copyright (C) 2009  Mickael Guessant
  *
  * This program is free software; you can redistribute it and/or
@@ -31,6 +31,8 @@ import davmail.exchange.dav.DavExchangeSession;
 import davmail.ui.tray.DavGatewayTray;
 import org.apache.log4j.Logger;
 
+import javax.naming.InvalidNameException;
+import javax.naming.ldap.Rdn;
 import javax.security.auth.callback.*;
 import javax.security.sasl.AuthorizeCallback;
 import javax.security.sasl.Sasl;
@@ -526,7 +528,8 @@ public class LdapConnection extends AbstractConnection {
             if (requestOperation == LDAP_REQ_BIND) {
                 reqBer.parseSeq(null);
                 ldapVersion = reqBer.parseInt();
-                userName = reqBer.parseString(isLdapV3());
+                // check for dn authentication
+                userName = extractRdnValue(reqBer.parseString(isLdapV3()));
                 if (reqBer.peekByte() == (Ber.ASN_CONTEXT | Ber.ASN_CONSTRUCTOR | 3)) {
                     // SASL authentication
                     reqBer.parseSeq(null);
@@ -535,11 +538,11 @@ public class LdapConnection extends AbstractConnection {
 
                     byte[] serverResponse;
                     CallbackHandler callbackHandler = new CallbackHandler() {
-                        public void handle(Callback[] callbacks) throws IOException, UnsupportedCallbackException {
+                        public void handle(Callback[] callbacks) throws IOException {
                             // look for username in callbacks
                             for (Callback callback : callbacks) {
                                 if (callback instanceof NameCallback) {
-                                    userName = ((NameCallback) callback).getDefaultName();
+                                    userName = extractRdnValue(((NameCallback) callback).getDefaultName());
                                     // get password from session pool
                                     password = ExchangeSessionFactory.getUserPassword(userName);
                                 }
@@ -579,7 +582,7 @@ public class LdapConnection extends AbstractConnection {
                         properties.put("javax.security.sasl.qop", "auth,auth-int");
                         saslServer = Sasl.createSaslServer(mechanism, "ldap", client.getLocalAddress().getHostAddress(), properties, callbackHandler);
                         if (saslServer == null) {
-                            throw new IOException("Unable to create SASL server for mechanism "+mechanism);
+                            throw new IOException("Unable to create SASL server for mechanism " + mechanism);
                         }
                         serverResponse = saslServer.evaluateResponse(EMPTY_BYTE_ARRAY);
                         status = LDAP_SASL_BIND_IN_PROGRESS;
@@ -688,6 +691,23 @@ public class LdapConnection extends AbstractConnection {
         }
     }
 
+    /**
+     * Extract rdn value from username
+     * @param dn distinguished name or username
+     * @return username
+     */
+    private String extractRdnValue(String dn) throws IOException {
+        if (dn.startsWith("uid=")) {
+            try {
+                return (String) new Rdn(dn.substring(0, Math.max(dn.indexOf(','), dn.length()))).getValue();
+            } catch (InvalidNameException e) {
+                throw new IOException(e);
+            }
+        } else {
+            return dn;
+        }
+    }
+
     protected void dumpBer(byte[] inbuf, int offset) {
         ByteArrayOutputStream baos = new ByteArrayOutputStream();
         Ber.dumpBER(baos, "LDAP request buffer\n", inbuf, 0, offset);
@@ -769,7 +789,7 @@ public class LdapConnection extends AbstractConnection {
 
         if ("uid".equalsIgnoreCase(attributeName) && sValue.equals(userName)) {
             // replace with actual alias instead of login name search, only in Dav mode
-            if (sValue.equals(userName) && session instanceof DavExchangeSession) {
+            if (session instanceof DavExchangeSession) {
                 sValue = session.getAlias();
                 DavGatewayTray.debug(new BundleMessage("LOG_LDAP_REPLACED_UID_FILTER", userName, sValue));
             }
@@ -1002,7 +1022,7 @@ public class LdapConnection extends AbstractConnection {
         os.flush();
     }
 
-    static interface LdapFilter {
+    interface LdapFilter {
         ExchangeSession.Condition getContactSearchFilter();
 
         Map<String, ExchangeSession.Contact> findInGAL(ExchangeSession session, Set<String> returningAttributes, int sizeLimit) throws IOException;
@@ -1351,7 +1371,7 @@ public class LdapConnection extends AbstractConnection {
             if (mappedAttribute != null) {
                 contactAttributeName = mappedAttribute;
             }
-        } else {
+        } else if (!"hassubordinates".equals(ldapAttributeName)){
             DavGatewayTray.debug(new BundleMessage("UNKNOWN_ATTRIBUTE", ldapAttributeName));
         }
         return contactAttributeName;
@@ -1439,7 +1459,6 @@ public class LdapConnection extends AbstractConnection {
                             // first search in contact
                             try {
                                 // check if this is a contact uid
-                                //noinspection ResultOfMethodCallIgnored
                                 Integer.parseInt(uid);
                                 persons = contactFind(session.isEqualTo("imapUid", uid), returningAttributes, sizeLimit);
                             } catch (NumberFormatException e) {
@@ -1645,6 +1664,8 @@ public class LdapConnection extends AbstractConnection {
                                 }
                             }
                             ldapPerson.put(ldapAttribute, value);
+                        } else if ("hassubordinates".equals(ldapAttribute)) {
+                            ldapPerson.put(ldapAttribute, "false");
                         }
                     }
                 }
@@ -1682,7 +1703,12 @@ public class LdapConnection extends AbstractConnection {
                     }
                 }
                 DavGatewayTray.debug(new BundleMessage("LOG_LDAP_REQ_SEARCH_SEND_PERSON", currentMessageId, ldapPerson.get("uid"), baseContext, ldapPerson));
-                sendEntry(currentMessageId, "uid=" + ldapPerson.get("uid") + baseContext, ldapPerson);
+
+                try {
+                    sendEntry(currentMessageId, new Rdn("uid", ldapPerson.get("uid")) + baseContext, ldapPerson);
+                } catch (InvalidNameException e) {
+                    throw new IOException(e);
+                }
             }
 
         }
