@@ -100,6 +100,8 @@ public class SettingsFrame extends JFrame {
     protected JTextField defaultDomainField;
     protected JCheckBox showStartupBannerCheckBox;
     protected JCheckBox disableGuiNotificationsCheckBox;
+    protected JCheckBox disableTrayActivitySwitchCheckBox;
+
     protected JCheckBox imapAutoExpungeCheckBox;
     protected JCheckBox enableKeepAliveCheckBox;
     protected JCheckBox popMarkReadOnRetrCheckBox;
@@ -109,7 +111,8 @@ public class SettingsFrame extends JFrame {
     protected JCheckBox smtpSaveInSentCheckBox;
 	protected JCheckBox imapAlwaysApproxMsgSizeCheckBox;
 
-	protected JTextField oauthClientIdField;
+    protected JTextField oauthTenantIdField;
+    protected JTextField oauthClientIdField;
     protected JTextField oauthRedirectUriField;
 
     JCheckBox osxHideFromDockCheckBox;
@@ -161,9 +164,8 @@ public class SettingsFrame extends JFrame {
         modeComboBox.addItem(Settings.EWS);
         modeComboBox.addItem(Settings.O365);
         modeComboBox.addItem(Settings.O365_MODERN);
-        if (isJavaFXAvailable()) {
-            modeComboBox.addItem(Settings.O365_INTERACTIVE);
-        }
+        modeComboBox.addItem(Settings.O365_INTERACTIVE);
+        modeComboBox.addItem(Settings.O365_MANUAL);
         modeComboBox.addItem(Settings.WEBDAV);
         modeComboBox.addItem(Settings.AUTO);
         modeComboBox.setSelectedItem(Settings.getProperty("davmail.mode", Settings.EWS));
@@ -261,19 +263,6 @@ public class SettingsFrame extends JFrame {
         return settingsPanel;
     }
 
-    private boolean isJavaFXAvailable() {
-        boolean isJavaFXAvailable = false;
-        try {
-            Class.forName("javafx.embed.swing.JFXPanel");
-            isJavaFXAvailable = true;
-        } catch (ClassNotFoundException e) {
-            // ignore
-        } catch (NoClassDefFoundError e) {
-            // ignore
-        }
-        return isJavaFXAvailable;
-    }
-
     protected JPanel getDelaysPanel() {
         JPanel delaysPanel = new JPanel(new GridLayout(4, 2));
         delaysPanel.setBorder(BorderFactory.createTitledBorder(BundleMessage.format("UI_DELAYS")));
@@ -440,12 +429,15 @@ public class SettingsFrame extends JFrame {
     }
 
     protected JPanel getOauthPanel() {
-        JPanel oAuthPanel = new JPanel(new GridLayout(2, 2));
+        JPanel oAuthPanel = new JPanel(new GridLayout(3, 2));
         oAuthPanel.setBorder(BorderFactory.createTitledBorder(BundleMessage.format("UI_OAUTH")));
 
+        oauthTenantIdField = new JTextField(Settings.getProperty("davmail.oauth.tenantId"), 20);
         oauthClientIdField = new JTextField(Settings.getProperty("davmail.oauth.clientId"), 20);
         oauthRedirectUriField = new JTextField(Settings.getProperty("davmail.oauth.redirectUri"), 20);
 
+        addSettingComponent(oAuthPanel, BundleMessage.format("UI_OAUTH_TENANTID"), oauthTenantIdField,
+                BundleMessage.format("UI_OAUTH_TENANTID_HELP"));
         addSettingComponent(oAuthPanel, BundleMessage.format("UI_OAUTH_CLIENTID"), oauthClientIdField,
                 BundleMessage.format("UI_OAUTH_CLIENTID_HELP"));
         addSettingComponent(oAuthPanel, BundleMessage.format("UI_OAUTH_REDIRECTURI"), oauthRedirectUriField,
@@ -479,7 +471,7 @@ public class SettingsFrame extends JFrame {
     }
 
     protected JPanel getOtherSettingsPanel() {
-        JPanel otherSettingsPanel = new JPanel(new GridLayout(15, 2));
+        JPanel otherSettingsPanel = new JPanel(new GridLayout(16, 2));
         otherSettingsPanel.setBorder(BorderFactory.createTitledBorder(BundleMessage.format("UI_OTHER")));
 
         folderSizeLimitField = new JTextField(Settings.getProperty("davmail.folderSizeLimit"), 6);
@@ -495,6 +487,8 @@ public class SettingsFrame extends JFrame {
         showStartupBannerCheckBox.setSelected(Settings.getBooleanProperty("davmail.showStartupBanner", true));
         disableGuiNotificationsCheckBox = new JCheckBox();
         disableGuiNotificationsCheckBox.setSelected(Settings.getBooleanProperty("davmail.disableGuiNotifications", false));
+        disableTrayActivitySwitchCheckBox =  new JCheckBox();
+        disableTrayActivitySwitchCheckBox.setSelected(Settings.getBooleanProperty("davmail.disableTrayActivitySwitch", false));
         imapAutoExpungeCheckBox = new JCheckBox();
         imapAutoExpungeCheckBox.setSelected(Settings.getBooleanProperty("davmail.imapAutoExpunge", true));
 		imapAlwaysApproxMsgSizeCheckBox = new JCheckBox();
@@ -526,6 +520,8 @@ public class SettingsFrame extends JFrame {
                 BundleMessage.format("UI_SHOW_STARTUP_BANNER_HELP"));
         addSettingComponent(otherSettingsPanel, BundleMessage.format("UI_DISABLE_GUI_NOTIFICATIONS"), disableGuiNotificationsCheckBox,
                 BundleMessage.format("UI_DISABLE_GUI_NOTIFICATIONS_HELP"));
+        addSettingComponent(otherSettingsPanel, BundleMessage.format("UI_DISABLE_TRAY_ACTIVITY_SWITCH"), disableTrayActivitySwitchCheckBox,
+                BundleMessage.format("UI_DISABLE_TRAY_ACTIVITY_SWITCH_HELP"));
         addSettingComponent(otherSettingsPanel, BundleMessage.format("UI_IMAP_AUTO_EXPUNGE"), imapAutoExpungeCheckBox,
                 BundleMessage.format("UI_IMAP_AUTO_EXPUNGE_HELP"));
         addSettingComponent(otherSettingsPanel, BundleMessage.format("UI_ALWAYS_APPROXIMATE_MSG_SIZE"), imapAlwaysApproxMsgSizeCheckBox,
@@ -669,6 +665,7 @@ public class SettingsFrame extends JFrame {
         defaultDomainField.setText(Settings.getProperty("davmail.defaultDomain"));
         showStartupBannerCheckBox.setSelected(Settings.getBooleanProperty("davmail.showStartupBanner", true));
         disableGuiNotificationsCheckBox.setSelected(Settings.getBooleanProperty("davmail.disableGuiNotifications", false));
+        disableTrayActivitySwitchCheckBox.setSelected(Settings.getBooleanProperty("davmail.disableTrayActivitySwitch", false));
         imapAutoExpungeCheckBox.setSelected(Settings.getBooleanProperty("davmail.imapAutoExpunge", true));
         imapAlwaysApproxMsgSizeCheckBox.setSelected(Settings.getBooleanProperty("davmail.imapAlwaysApproxMsgSize", false));
         enableKeepAliveCheckBox.setSelected(Settings.getBooleanProperty("davmail.enableKeepAlive", false));
@@ -687,6 +684,7 @@ public class SettingsFrame extends JFrame {
         pkcs11LibraryField.setText(Settings.getProperty("davmail.ssl.pkcs11Library"));
         pkcs11ConfigField.setText(Settings.getProperty("davmail.ssl.pkcs11Config"));
 
+        oauthTenantIdField.setText(Settings.getProperty("davmail.oauth.tenantId"));
         oauthClientIdField.setText(Settings.getProperty("davmail.oauth.clientId"));
         oauthRedirectUriField.setText(Settings.getProperty("davmail.oauth.redirectUri"));
 
@@ -838,6 +836,7 @@ public class SettingsFrame extends JFrame {
                 Settings.setProperty("davmail.defaultDomain", String.valueOf(defaultDomainField.getText()));
                 Settings.setProperty("davmail.showStartupBanner", String.valueOf(showStartupBannerCheckBox.isSelected()));
                 Settings.setProperty("davmail.disableGuiNotifications", String.valueOf(disableGuiNotificationsCheckBox.isSelected()));
+                Settings.setProperty("davmail.disableTrayActivitySwitch", String.valueOf(disableTrayActivitySwitchCheckBox.isSelected()));
                 Settings.setProperty("davmail.imapAutoExpunge", String.valueOf(imapAutoExpungeCheckBox.isSelected()));
                 Settings.setProperty("davmail.imapAlwaysApproxMsgSize", String.valueOf(imapAlwaysApproxMsgSizeCheckBox.isSelected()));
                 Settings.setProperty("davmail.enableKeepAlive", String.valueOf(enableKeepAliveCheckBox.isSelected()));
@@ -859,6 +858,7 @@ public class SettingsFrame extends JFrame {
                 Settings.setProperty("davmail.ssl.pkcs11Library", pkcs11LibraryField.getText());
                 Settings.setProperty("davmail.ssl.pkcs11Config", pkcs11ConfigField.getText());
 
+                Settings.setProperty("davmail.oauth.tenantId", oauthTenantIdField.getText());
                 Settings.setProperty("davmail.oauth.clientId", oauthClientIdField.getText());
                 Settings.setProperty("davmail.oauth.redirectUri", oauthRedirectUriField.getText());
 
