@@ -61,7 +61,7 @@ public final class DavGatewayTray {
      * Switch tray icon between active and standby icon.
      */
     public static void switchIcon() {
-        if (davGatewayTray != null) {
+        if (davGatewayTray != null && !Settings.getBooleanProperty("davmail.disableTrayActivitySwitch")) {
             if (System.currentTimeMillis() - lastIconSwitch > ICON_SWITCH_MINIMUM_DELAY) {
                 davGatewayTray.switchIcon();
                 lastIconSwitch = System.currentTimeMillis();
@@ -348,8 +348,13 @@ public final class DavGatewayTray {
         Color backgroundColor = null;
         String backgroundColorString = Settings.getProperty("davmail.trayBackgroundColor");
 
-        boolean isKDE = "KDE".equals(System.getenv("XDG_CURRENT_DESKTOP"));
-        boolean isUnity = "Unity".equals(System.getenv("XDG_CURRENT_DESKTOP"));
+        String xdgCurrentDesktop = System.getenv("XDG_CURRENT_DESKTOP");
+
+        boolean isKDE = "KDE".equals(xdgCurrentDesktop);
+        boolean isXFCE = "XFCE".equals(xdgCurrentDesktop);
+        boolean isUnity = "Unity".equals(xdgCurrentDesktop);
+        boolean isCinnamon = "X-Cinnamon".equals(xdgCurrentDesktop);
+
         if (backgroundColorString == null || backgroundColorString.length() == 0) {
             // define color for default theme
             if (isKDE) {
@@ -358,6 +363,12 @@ public final class DavGatewayTray {
             if (isUnity) {
                 backgroundColorString = "#4D4B45";
             }
+            if (isXFCE) {
+                backgroundColorString = "#E8E8E7";
+            }
+            if (isCinnamon) {
+                backgroundColorString = "#2E2E2E";
+            }
         }
 
         int imageType = BufferedImage.TYPE_INT_ARGB;
@@ -370,21 +381,26 @@ public final class DavGatewayTray {
             imageType = BufferedImage.TYPE_INT_RGB;
         }
 
-        if (backgroundColor != null || isKDE || isUnity) {
+        if (backgroundColor != null || isKDE || isUnity || isXFCE) {
             int width = image.getWidth();
             int height = image.getHeight();
             int x = 0;
             int y = 0;
-            if (isKDE) {
+            if (isKDE || isXFCE) {
                 width = 22;
                 height = 22;
-                x = 4;
-                y = 4;
+                x = 3;
+                y = 3;
             } else if (isUnity) {
                 width = 22;
                 height = 24;
                 x = 4;
                 y = 4;
+            } else if (isCinnamon) {
+                width = 24;
+                height = 24;
+                x = 4;
+                y = 4;
             }
             BufferedImage bufferedImage = new BufferedImage(width, height, imageType);
             Graphics2D graphics = bufferedImage.createGraphics();
