@@ -35,7 +35,7 @@ import java.util.Locale;
 /**
  * IMAP tests, an instance of DavMail Gateway must be available
  */
-@SuppressWarnings({"JavaDoc", "UseOfSystemOutOrSystemErr"})
+@SuppressWarnings({"UseOfSystemOutOrSystemErr"})
 public class TestImap extends AbstractImapTestCase {
 
     protected String getLastMonth() {
@@ -50,7 +50,7 @@ public class TestImap extends AbstractImapTestCase {
         resetTestFolder();
     }
 
-    public void testCreateMessage() throws IOException, MessagingException {
+    public void testCreateMessage() throws IOException {
         resetTestFolder();
         appendMessage();
     }
@@ -330,6 +330,22 @@ public class TestImap extends AbstractImapTestCase {
         assertEquals(". OK UID FETCH completed", readFullAnswer("."));
     }
 
+    public void testBodyFetch() throws IOException {
+        resetTestFolder();
+        appendMessage();
+
+        writeLine(". UID FETCH " + messageUid + " (UID BODY[])");
+        assertEquals(". OK UID FETCH completed", readFullAnswer("."));
+    }
+
+    public void testRfc822Fetch() throws IOException {
+        resetTestFolder();
+        appendMessage();
+
+        writeLine(". UID FETCH " + messageUid + " (UID RFC822)");
+        assertEquals(". OK UID FETCH completed", readFullAnswer("."));
+    }
+
     public void testFetchInternalDate() throws IOException {
         resetTestFolder();
         appendMessage();
@@ -503,7 +519,7 @@ public class TestImap extends AbstractImapTestCase {
         assertEquals(". OK SEARCH completed", readFullAnswer("."));
     }
 
-    public void testDraftMessageMessageId() throws IOException, InterruptedException, MessagingException {
+    public void testDraftMessageMessageId() throws IOException, MessagingException {
         resetTestFolder();
         appendMessage();
 
@@ -693,7 +709,7 @@ public class TestImap extends AbstractImapTestCase {
         assertEquals(". OK UID FETCH completed", readFullAnswer("."));
     }
 
-    public void testCopyMessage() throws IOException, InterruptedException, MessagingException {
+    public void testCopyMessage() throws IOException {
         resetTestFolder();
         appendMessage();
 
@@ -711,4 +727,27 @@ public class TestImap extends AbstractImapTestCase {
 
     }
 
+    public void testCopyMessageMissingFolder() throws IOException {
+        resetTestFolder();
+        appendMessage();
+
+        writeLine(". UID FETCH 1:* (FLAGS)");
+        String messageLine = readLine();
+        int uidIndex = messageLine.indexOf("UID ") + 4;
+        messageUid = messageLine.substring(uidIndex, messageLine.indexOf(' ', uidIndex));
+        assertEquals(". OK UID FETCH completed", readFullAnswer("."));
+
+        writeLine(". UID COPY " + messageUid + " Missing");
+        assertEquals(". NO [TRYCREATE] Folder 'Missing' not found", readFullAnswer("."));
+
+    }
+
+    public void testSearchNotUid() throws IOException {
+        resetTestFolder();
+        appendMessage();
+
+        writeLine(". UID SEARCH NOT UID 1");
+        assertEquals("* SEARCH", readLine());
+        assertEquals(". OK SEARCH completed", readFullAnswer("."));
+    }
 }
